import "dart:async";
import 'package:cross_connectivity/cross_connectivity.dart';
import "package:flutter/material.dart";
import 'package:shared_preferences/shared_preferences.dart';
import 'package:wakelock/wakelock.dart';

class VertticeUIState extends ChangeNotifier {
  VertticeUIState() {
    _initConnectivity();
    _initDeviceAwake();
    _initTheme();
  }

  // // // VARS
  bool _connectToTheInternet = false;
  bool _keepDeviceAwake = true;
  bool _formInReadonlyView = false;
  Color _themeColor = Colors.yellow[700]!;
  Color _themeTextColor = Colors.black;
  Color _themeTextOffColor = Colors.grey;
  bool _isDarkTheme = false;

  // // //  GETS
  bool get connectToTheInternet => _connectToTheInternet;
  bool get keepDeviceAwake => _keepDeviceAwake;
  bool get formInReadonlyView => _formInReadonlyView;
  bool get isDarkTheme => _isDarkTheme;
  Color get themeColor => _themeColor;
  Color get themeTextColor => _themeTextColor;
  Color get themeTextOffColor => _themeTextOffColor;

  // // //  SETS
  void setFormInReadonlyView(bool val) {
    _formInReadonlyView = val;
    notifyListeners();
  }

  Future<void> setKeepDeviceAwake(bool val) async {
    final pref = await SharedPreferences.getInstance();
    await pref.setBool("awake", val);
    Wakelock.toggle(enable: val);
    _keepDeviceAwake = val;
    notifyListeners();
  }

  void setConnectToTheInternet(bool val) {
    _connectToTheInternet = val;
    notifyListeners();
  }

  Future _initDeviceAwake() async {
    final pref = await SharedPreferences.getInstance();
    final awake = pref.getBool("awake");
    if (awake == null) {
      await pref.setBool("awake", true);
    }
    setKeepDeviceAwake(awake ?? true);
  }

  Future<void> _initConnectivity() async {
    final connectivityResult = await (Connectivity().checkConnectivity());
    setConnectToTheInternet(connectivityResult != ConnectivityStatus.none);
    Connectivity().onConnectivityChanged.listen((ConnectivityStatus result) {
      setConnectToTheInternet(result != ConnectivityStatus.none);
    });
  }

  Future<void> setThemTextOffColor(Color color) async {
    _themeTextOffColor = color;
    notifyListeners();
  }

  Future<void> setThemTextColor(Color color) async {
    _themeTextColor = color;
    notifyListeners();
  }

  Future<void> setThemeColor(Color color) async {
    _themeColor = color;
    notifyListeners();
  }

  Future<void> setDarkTheme(bool dark) async {
    final pref = await SharedPreferences.getInstance();
    await pref.setBool("dark", dark);
    _isDarkTheme = dark;
    notifyListeners();
  }

  Future _initTheme() async {
    final pref = await SharedPreferences.getInstance();
    final dark = pref.getBool("dark") ?? false;
    await setDarkTheme(dark);
  }
}
