import 'package:verttice_logic/verttice_logic.dart';
import "package:verttice_ui/src/const/icons.dart";
import "package:flutter/material.dart";
import "package:html_editor_enhanced/html_editor.dart";
import "package:universal_html/parsing.dart";
import 'package:verttice_ui/src/widgets/border_label.dart';
import 'package:verttice_ui/src/widgets/dialogs/full_page_dialog.dart';
import 'package:verttice_ui/src/widgets/themed_app_bar.dart';

class RichTextFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;

  const RichTextFormFactory({
    Key? key,
    required this.displayName,
    required this.name,
    required this.onChanged,
    this.state,
    this.value,
  }) : super(key: key);
  @override
  _TextFormState createState() => _TextFormState();
}

class _TextFormState extends State<RichTextFormFactory> {
  String _value = "";
  String _viewValue = "";
  final HtmlEditorController _richTextController = HtmlEditorController();
  late FocusNode _focusNode;

  @override
  void initState() {
    super.initState();
    _viewValue = _parseHtmlString(DataClassUtils.dynamicToString(widget.value));
    _value = widget.value;

    _focusNode = FocusNode();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant RichTextFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _viewValue =
          _parseHtmlString(DataClassUtils.dynamicToString(widget.value));
      _value = widget.value;

      _focusNode = FocusNode();
    }
  }

  String _parseHtmlString(String htmlString) {
    final String parsedString = parseHtmlDocument(
          htmlString,
        ).documentElement?.text ??
        "";
    return parsedString;
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      onPressed: () async {
        await fullPageDialog(
            context: context,
            builder: (BuildContext context) => Builder(builder: (context) {
                  return Scaffold(
                    appBar: ThemedAppBar(
                      actions: [
                        IconButton(
                            onPressed: () async {
                              final text = await _richTextController.getText();
                              setState(() {
                                _value = text;
                                _viewValue = _parseHtmlString(text);
                              });
                              widget.onChanged(widget.name, text);
                              widget.state?.didChange(text);
                              Navigator.pop(context);
                            },
                            icon: ThemedIcons.check())
                      ],
                    ),
                    body: HtmlEditor(
                      controller: _richTextController,
                      htmlEditorOptions: HtmlEditorOptions(
                        hint: "Your text here",
                        initialText: _value,
                      ),
                      htmlToolbarOptions: const HtmlToolbarOptions(
                        defaultToolbarButtons: [
                          StyleButtons(),
                          FontSettingButtons(fontSizeUnit: false),
                          FontButtons(clearAll: false),
                          ColorButtons(),
                          ListButtons(listStyles: false),
                          ParagraphButtons(
                            textDirection: false,
                            lineHeight: false,
                            caseConverter: false,
                          ),
                          InsertButtons(
                            video: false,
                            audio: false,
                            table: false,
                            hr: false,
                            otherFile: false,
                            picture: false,
                          ),
                        ],
                      ),
                      otherOptions: const OtherOptions(
                        height: 400,
                      ),
                    ),
                  );
                }));
      },
      child: LayoutBuilder(builder: (context, constraints) {
        return SizedBox(
          width: constraints.maxWidth,
          child: Focus(
            focusNode: _focusNode,
            child: MouseRegion(
              onEnter: (_) {
                setState(() {
                  _focusNode.requestFocus();
                });
              },
              onExit: (_) {
                setState(() {
                  _focusNode.unfocus();
                });
              },
              child: Tooltip(
                message: _viewValue,
                child: SelectableText(
                  _viewValue,
                  maxLines: 3,
                  style: const TextStyle(
                    overflow: TextOverflow.fade,
                  ),
                ),
              ),
            ),
          ),
        );
      }),
    );
  }
}
