import "package:flutter/material.dart";

class ThemedAppBar extends StatelessWidget with PreferredSizeWidget {
  final String? title;
  final Color? titleColor;
  final List<Widget>? actions;
  final Widget? bottomSection;
  final Color? backgroundColor;
  final bool navigateBackButton;
  final Widget? leading;
  final double? appBarHeight;

  const ThemedAppBar({
    Key? key,
    this.title,
    this.titleColor,
    this.actions,
    this.bottomSection,
    this.backgroundColor,
    this.navigateBackButton = true,
    this.leading,
    this.appBarHeight,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppBar(
      leading: navigateBackButton ? leading : (leading ?? Container()),
      title: (title != null
          ? SelectableText(
              title!,
              maxLines: 1,
              style: TextStyle(
                color: titleColor,
              ),
            )
          : null),
      actions: actions,
      centerTitle: true,
      bottom: bottomSection != null
          ? PreferredSize(
              child: bottomSection!,
              preferredSize: const Size(double.infinity, 45.0),
            )
          : null,
      backgroundColor: backgroundColor,
      elevation: 0.5,
      toolbarHeight: appBarHeight ?? 48,
    );
  }

  @override
  Size get preferredSize => const Size(double.infinity, 50);
}
