import "package:flutter/material.dart";
import 'package:verttice_ui/src/config/config.dart';
import 'package:verttice_ui/src/widgets/themed_progress.dart';
import 'package:verttice_ui/src/widgets/themed_text.dart';
import 'package:verttice_ui/src/widgets/themed_text_button.dart';

class ThemedMessage extends StatefulWidget {
  final String? message;
  final double? width;
  final double? height;
  final bool isHaveSiginButton;
  final bool showLoading;
  final List<Widget> actions;

  const ThemedMessage({
    Key? key,
    this.message,
    this.isHaveSiginButton = false,
    this.width,
    this.height,
    this.showLoading = false,
    this.actions = const [],
  }) : super(key: key);

  @override
  _ThemedMessageState createState() => _ThemedMessageState();
}

class _ThemedMessageState extends State<ThemedMessage> {
  @override
  Widget build(BuildContext context) {
    final String? message = widget.message;
    final double? width = widget.width;
    final double? height = widget.height;
    final bool showLoading = widget.showLoading;
    final bool isHaveSiginButton = widget.isHaveSiginButton;
    return Scaffold(
      body: LayoutBuilder(
          builder: (BuildContext context, BoxConstraints constraints) {
        final double _width = width ??
            (constraints.maxWidth == double.infinity
                ? 400
                : constraints.maxWidth);
        final double _height = height ??
            (constraints.maxHeight == double.infinity
                ? 400
                : constraints.maxHeight);

        return Scaffold(
          body: SizedBox(
            height: _height,
            width: _width,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                if (showLoading)
                  const Center(
                    child: Padding(
                      padding: EdgeInsets.all(15),
                      child: SizedBox(
                        height: 30,
                        width: 30,
                        child: ThemedProgress(),
                      ),
                    ),
                  ),
                if (message != null)
                  Center(
                    child: ThemedText(message),
                  ),
                if (isHaveSiginButton)
                  Padding(
                    padding: const EdgeInsets.all(30.0),
                    child: Center(
                      child: SizedBox(
                        width: 300,
                        child: ThemedTextButton(
                          "Go to sign in",
                          onPressed: () async {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) =>
                                    VertticeUIConfig.instance.signInPage,
                              ),
                            );
                          },
                        ),
                      ),
                    ),
                  ),
                Padding(
                  padding: const EdgeInsets.all(20),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: widget.actions
                        .map((e) => Padding(
                              padding: const EdgeInsets.all(2),
                              child: e,
                            ))
                        .toList(),
                  ),
                ),
              ],
            ),
          ),
        );
      }),
    );
  }
}
