import 'package:flutter/material.dart';
import 'package:verttice_ui/src/widgets/form_factory/text_form.dart';

class ThemedSearchList<T> extends StatelessWidget {
  final String searchText;
  final Function(String) searchCallback;
  final List<Widget>? actions;
  final List<T> items;
  final String Function(T) itemLabelCallback;
  final void Function(T) onSelectedItem;

  const ThemedSearchList({
    Key? key,
    required this.searchText,
    required this.searchCallback,
    required this.items,
    required this.itemLabelCallback,
    required this.onSelectedItem,
    this.actions,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        SizedBox(
          height: 55,
          child: Row(
            children: [
              Expanded(
                child: TextFormFactory(
                  showStandartBorder: false,
                  displayName: 'Search',
                  name: 'search',
                  value: searchText,
                  onChanged: (name, search) {
                    searchCallback(search);
                  },
                ),
              ),
              if (actions != null)
                ...actions!
                    .map((e) => Padding(
                          padding: const EdgeInsets.symmetric(horizontal: 4),
                          child: e,
                        ))
                    .toList()
            ],
          ),
        ),
        Expanded(
          child: ListView.builder(
            itemCount: items.length,
            itemBuilder: (context, index) {
              final item = items[index];

              return InkWell(
                onTap: () {
                  onSelectedItem(item);
                },
                child: SizedBox(
                  height: 70,
                  child: Center(
                    child: Text(
                      itemLabelCallback(item),
                    ),
                  ),
                ),
              );
            },
          ),
        ),
      ],
    );
  }
}
